Imapy is written by Vladimir Goncharov.


Special thanks to
```````````````````````
- `Beauhurst <https://github.com/Beauhurst>` _ (opensource@beauhurst.com)
- `Thomas Bird <https://github.com/thomasbird>`_ (British parsing rules)
- `Thomas Funk <https://github.com/tomfunk>`_ (thomasfunk10@gmail.com)
- `KCzar <https://github.com/KCzar>`_
